store property
The flux Store instance(s) to be used by a FluxUiComponent2 instance, or a reference to one.
** Required **
Instead of storing state within this component via setState, it is recommended that data be
pulled directly from these stores. This ensures that the data being used is always up to date
and leaves the state management logic to the stores.
If this component only needs data from a single Store, then StoresT
should be an instance of Store. This allows the default implementation
of redrawOn to automatically subscribe to the store.
If this component needs data from multiple Store instances, then
StoresT should be a class that provides access to these multiple stores.
Then, you can explicitly select the Store instances that should be
listened to by overriding _FluxComponentMixin.redrawOn.
Implementation
@override
@override
StoresT get store =>
(props[_$key__store__FluxUiPropsMixin] ?? null) as StoresT;
The flux Store instance(s) to be used by a FluxUiComponent2 instance, or a reference to one.
** Required **
Instead of storing state within this component via setState, it is recommended that data be
pulled directly from these stores. This ensures that the data being used is always up to date
and leaves the state management logic to the stores.
If this component only needs data from a single Store, then StoresT
should be an instance of Store. This allows the default implementation
of redrawOn to automatically subscribe to the store.
If this component needs data from multiple Store instances, then
StoresT should be a class that provides access to these multiple stores.
Then, you can explicitly select the Store instances that should be
listened to by overriding _FluxComponentMixin.redrawOn.
Implementation
@override
@override
set store(StoresT value) => props[_$key__store__FluxUiPropsMixin] = value;