CallbackUtil3Arg<T1, T2, T3> class

Generic strongly-typed callback chaining utilities for callbacks with three arguments.

Inheritance

Constructors

CallbackUtil3Arg()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
noop Callback3Arg<T1, T2, T3>
A callback that does nothing.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chain(covariant Callback3Arg<T1, T2, T3>? a, covariant Callback3Arg<T1, T2, T3>? b) Callback3Arg<T1, T2, T3>
Returns a strongly-typed chained callback that calls through to the two provided callbacks, a and b, in order. Useful for executing multiple callbacks where only a single callback is accepted.
override
chainFromList(covariant List<Callback3Arg<T1, T2, T3>?> callbacks) Callback3Arg<T1, T2, T3>
Returns a strongly-typed chained callback that calls through to the list of provided callbacks in order. Useful for executing multiple callbacks where only a single callback is accepted.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited