SyntheticMouseEvent class

A SyntheticEvent wrapper that is specifically backed by a MouseEvent.

See developer.mozilla.org/en-US/docs/Web/API/MouseEvent

Inheritance
Available extensions
Annotations
  • @JS.new()

Properties

altKey bool
Whether the alt key was down when this event was fired.
no setter
bubbles bool
Indicates whether the Event bubbles up through the DOM or not.
no setterinherited
button num
The button number that was pressed (if applicable) when this event was fired.
no setter
buttons num
The buttons being depressed (if any) when this event was fired.
no setter
cancelable bool
Indicates whether the Event is cancelable or not.
no setterinherited
clientX num
The X coordinate of the mouse pointer in local (DOM content) coordinates.
no setter
clientY num
The Y coordinate of the mouse pointer in local (DOM content) coordinates.
no setter
ctrlKey bool
Whether the Ctrl key was active when this event was generated.
no setter
currentTarget → dynamic
Identifies the current target for the event, as the Event traverses the DOM.
no setterinherited
dataTransfer → SyntheticDataTransfer?

Available on SyntheticMouseEvent, provided by the DataTransferHelper extension

The data that is transferred during a drag and drop interaction.
no setter
defaultPrevented bool
Indicates whether or not preventDefault was called on the event.
no setterinherited
eventPhase num
Indicates which phase of the Event flow is currently being evaluated.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isAnimationEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticAnimationEvent.
no setter
isClipboardEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticClipboardEvent.
no setter
isCompositionEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticCompositionEvent.
no setter
isFocusEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticFocusEvent.
no setter
isKeyboardEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticKeyboardEvent.
no setter
isMouseEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticMouseEvent.
no setter
isPointerEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticPointerEvent.
no setter
isTouchEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticTouchEvent.
no setter
isTransitionEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticTransitionEvent.
no setter
isTrusted bool
Is true when the Event was generated by a user action, and false when the Event was created or modified by a script or dispatched via EventTarget.dispatchEvent.
no setterinherited
isUiEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticUIEvent.
no setter
isWheelEvent bool

Available on SyntheticEvent, provided by the SyntheticEventTypeHelpers extension

Uses Duck Typing to detect if the event instance is a SyntheticWheelEvent.
no setter
metaKey bool
Whether the meta key was down when this event was fired.
no setter
nativeEvent → dynamic
The native browser event this wraps.
no setterinherited
pageX num
The X coordinate of the mouse pointer relative to the whole document.
no setter
pageY num
The Y coordinate of the mouse pointer relative to the whole document.
no setter
relatedTarget → dynamic
The secondary target for this event, if there is one.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenX num
The X coordinate of the mouse pointer in global (screen) coordinates.
no setter
screenY num
The Y coordinate of the mouse pointer in global (screen) coordinates.
no setter
shiftKey bool
Whether the Shift key was active when this event was generated.
no setter
stopPropagation → dynamic
Prevents further propagation of the current event.
no setterinherited
target → dynamic
A reference to the object that dispatched the event. It is different from currentTarget when the Event handler is called when eventPhase is Event.BUBBLING_PHASE or Event.CAPTURING_PHASE.
no setterinherited
timeStamp num
Returns the time (in milliseconds) at which the Event was created.
no setterinherited
type String
Returns a string containing the type of event. It is set when the Event is constructed and is the name commonly used to refer to the specific event.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
Cancels the Event if it is cancelable, without stopping further propagation of the event.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited