UngeneratedError class
Thrown when stubbed code (usually annotated with ToBeGenerated) that expects to be
overridden by generated code is called unexpectedly.
Usually this is due to improper usage of the code-generating builder.
- Inheritance
- Implemented types
Constructors
- UngeneratedError({String? message, Symbol? member})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited