onChange property
Callback for when the content of a form element, the selection, or the checked state have changed (for , ,
Implementation
@override
FormEventCallback? get onChange => (props[_$key__onChange___$UbiquitousDomPropsMixin] ?? null) as FormEventCallback?;
Callback for when the content of a form element, the selection, or the checked state have changed (for , ,
Implementation
@override
set onChange(FormEventCallback? value) => props[_$key__onChange___$UbiquitousDomPropsMixin] = value;