onCut property
Callback for when the user cuts the content of an element
Implementation
@override
ClipboardEventCallback? get onCut => (props[_$key__onCut___$UbiquitousDomPropsMixin] ?? null) as ClipboardEventCallback?;
Callback for when the user cuts the content of an element
Implementation
@override
set onCut(ClipboardEventCallback? value) => props[_$key__onCut___$UbiquitousDomPropsMixin] = value;