onMouseOver property

  1. @override
MouseEventCallback? get onMouseOver
inherited

Callback for when the pointer is moved onto an element, or onto one of its children

Implementation

@override
MouseEventCallback? get onMouseOver => (props[_$key__onMouseOver___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
  1. @override
set onMouseOver (MouseEventCallback? value)
inherited

Callback for when the pointer is moved onto an element, or onto one of its children

Implementation

@override
set onMouseOver(MouseEventCallback? value) => props[_$key__onMouseOver___$UbiquitousDomPropsMixin] = value;