onPointerOut property
Callback for when the pointer is moved out of an element, or out of one of its children
Implementation
@override
PointerEventCallback? get onPointerOut => (props[_$key__onPointerOut___$UbiquitousDomPropsMixin] ?? null) as PointerEventCallback?;
Callback for when the pointer is moved out of an element, or out of one of its children
Implementation
@override
set onPointerOut(PointerEventCallback? value) => props[_$key__onPointerOut___$UbiquitousDomPropsMixin] = value;