onWillHide property

  1. @override
Callback? get onWillHide
override

Optional callback that fires before the AbstractTransitionComponent is hidden.

Returning false will cancel default behavior, and the AbstractTransitionComponent will remain visible.

Implementation

@override
Callback? get onWillHide => (props[_$key__onWillHide__TransitionPropsMixin] ?? null) as Callback?;
  1. @override
set onWillHide (Callback? value)
override

Optional callback that fires before the AbstractTransitionComponent is hidden.

Returning false will cancel default behavior, and the AbstractTransitionComponent will remain visible.

Implementation

@override
set onWillHide(Callback? value) => props[_$key__onWillHide__TransitionPropsMixin] = value;