onMouseLeave property
Callback for when the pointer is moved out of an element
Implementation
@override
MouseEventCallback? get onMouseLeave => (props[_$key__onMouseLeave___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
Callback for when the pointer is moved out of an element
Implementation
@override
set onMouseLeave(MouseEventCallback? value) => props[_$key__onMouseLeave___$UbiquitousDomPropsMixin] = value;