onMouseOut property
Callback for when a user moves the mouse pointer out of an element, or out of one of its children
Implementation
@override
MouseEventCallback? get onMouseOut => (props[_$key__onMouseOut___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
Callback for when a user moves the mouse pointer out of an element, or out of one of its children
Implementation
@override
set onMouseOut(MouseEventCallback? value) => props[_$key__onMouseOut___$UbiquitousDomPropsMixin] = value;