$transitionPhase property
The current transition phase, derived from the current WithTransitionPropsMixin.isShown value.
Do not set directly.
Implementation
@override
@protected
TransitionPhase get $transitionPhase => (state[_$key__$transitionPhase__WithTransitionState] ?? null) as TransitionPhase;
The current transition phase, derived from the current WithTransitionPropsMixin.isShown value.
Do not set directly.
Implementation
@override
@protected
set $transitionPhase(TransitionPhase value) => state[_$key__$transitionPhase__WithTransitionState] = value;