onMouseOver property
Callback for when the pointer is moved onto an element, or onto one of its children
Implementation
@override
MouseEventCallback? get onMouseOver => (props[_$key__onMouseOver___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
Callback for when the pointer is moved onto an element, or onto one of its children
Implementation
@override
set onMouseOver(MouseEventCallback? value) => props[_$key__onMouseOver___$UbiquitousDomPropsMixin] = value;