tabIndex property

  1. @override
dynamic get tabIndex
inherited

Whether the element if focusable. Must be a valid integer or String of valid integer.

Implementation

set style(Map<String, dynamic>? value) => _raw$UbiquitousDomProps$style = value;  /// Whether the element if focusable.
  /// Must be a valid integer or String of valid integer.
  ///
  /// <!-- Generated from [_$UbiquitousDomPropsMixin.tabIndex] -->
  @override
  dynamic get tabIndex => (props[_$key__tabIndex___$UbiquitousDomPropsMixin] ?? null) as dynamic;
  1. @override
set tabIndex (dynamic value)
inherited

Whether the element if focusable. Must be a valid integer or String of valid integer.

Implementation

@override
set tabIndex(dynamic value) => props[_$key__tabIndex___$UbiquitousDomPropsMixin] = value;