onKeyDown property
Callback for when the user is pressing a key
Implementation
@override
KeyboardEventCallback? get onKeyDown => (props[_$key__onKeyDown___$UbiquitousDomPropsMixin] ?? null) as KeyboardEventCallback?;
Callback for when the user is pressing a key
Implementation
@override
set onKeyDown(KeyboardEventCallback? value) => props[_$key__onKeyDown___$UbiquitousDomPropsMixin] = value;