onPointerOver property
Callback for when the pointer is moved onto an element, or onto one of its children
Implementation
@override
PointerEventCallback? get onPointerOver => (props[_$key__onPointerOver___$UbiquitousDomPropsMixin] ?? null) as PointerEventCallback?;
Callback for when the pointer is moved onto an element, or onto one of its children
Implementation
@override
set onPointerOver(PointerEventCallback? value) => props[_$key__onPointerOver___$UbiquitousDomPropsMixin] = value;