onDragStart property
Callback for when the user starts to drag an element
Implementation
@override
MouseEventCallback? get onDragStart => (props[_$key__onDragStart___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
Callback for when the user starts to drag an element
Implementation
@override
set onDragStart(MouseEventCallback? value) => props[_$key__onDragStart___$UbiquitousDomPropsMixin] = value;