context property
You may provide a context instance. If you do so, you will need to provide the same context instance to all of your connected components as well.
Implementation
@override
dynamic get context => (props[_$key__context__ReduxProviderPropsMixin] ?? null) as dynamic;
You may provide a context instance. If you do so, you will need to provide the same context instance to all of your connected components as well.
Implementation
@override
set context(dynamic value) => props[_$key__context__ReduxProviderPropsMixin] = value;