onContextMenu property
Callback for when the user right-clicks on an element to open a context menu
Implementation
@override
MouseEventCallback? get onContextMenu => (props[_$key__onContextMenu___$UbiquitousDomPropsMixin] ?? null) as MouseEventCallback?;
Callback for when the user right-clicks on an element to open a context menu
Implementation
@override
set onContextMenu(MouseEventCallback? value) => props[_$key__onContextMenu___$UbiquitousDomPropsMixin] = value;