onCopy property
Callback for when the user copies the content of an element
Implementation
@override
ClipboardEventCallback? get onCopy => (props[_$key__onCopy___$UbiquitousDomPropsMixin] ?? null) as ClipboardEventCallback?;
Callback for when the user copies the content of an element
Implementation
@override
set onCopy(ClipboardEventCallback? value) => props[_$key__onCopy___$UbiquitousDomPropsMixin] = value;