onPointerDown property
Callback for when the pointer becomes active over an element
Implementation
@override
PointerEventCallback? get onPointerDown => (props[_$key__onPointerDown___$UbiquitousDomPropsMixin] ?? null) as PointerEventCallback?;
Callback for when the pointer becomes active over an element
Implementation
@override
set onPointerDown(PointerEventCallback? value) => props[_$key__onPointerDown___$UbiquitousDomPropsMixin] = value;