onPointerLeave property
Callback for when the pointer is moved out of an element
Implementation
@override
PointerEventCallback? get onPointerLeave => (props[_$key__onPointerLeave___$UbiquitousDomPropsMixin] ?? null) as PointerEventCallback?;
Callback for when the pointer is moved out of an element
Implementation
@override
set onPointerLeave(PointerEventCallback? value) => props[_$key__onPointerLeave___$UbiquitousDomPropsMixin] = value;