AbstractComponent class
Annotation used with the over_react builder to declare an abstract UiComponent class for an abstract component.
@AbstractComponent()
abstract class QuxComponent<TProps extends QuxProps> extends UiComponent<TProps> {}
Deprecated. Use the AbstractComponent2 annotation alongside UiComponent2 / UiStatefulComponent2 instead.
- Implementers
- Annotations
-
- @Deprecated('4.0.0')
Constructors
- AbstractComponent()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited