onWillHide property
Optional callback that fires before the AbstractTransitionComponent is hidden.
Returning false will cancel default behavior, and the AbstractTransitionComponent will remain visible.
Implementation
@override
Callback? get onWillHide => (props[_$key__onWillHide__TransitionPropsMixin] ?? null) as Callback?;
Optional callback that fires before the AbstractTransitionComponent is hidden.
Returning false will cancel default behavior, and the AbstractTransitionComponent will remain visible.
Implementation
@override
set onWillHide(Callback? value) => props[_$key__onWillHide__TransitionPropsMixin] = value;